@@ -8,7 +8,8 @@ import warnings
 from pytest import mark, raises
 
 from wand.color import Color
-from wand.exceptions import (MissingDelegateError, OptionError)
+from wand.exceptions import (MissingDelegateError, OptionError,
+                             WandRuntimeError)
 from wand.image import Image
 from wand.font import Font
 from wand.version import MAGICK_VERSION_NUMBER
@@ -119,7 +120,7 @@ def test_auto_threshold():
         assert was != img.signature
 
 
-def test_black_threshold(fx_asset):
+def test_black_threshold():
     with Image(filename='rose:') as img:
         was = img.signature
         img.black_threshold(Color('gray(50%)'))
@@ -129,7 +130,7 @@ def test_black_threshold(fx_asset):
             img.white_threshold(0xDEADBEEF)
 
 
-def test_blue_shift(fx_asset):
+def test_blue_shift():
     with Image(filename='rose:') as img:
         was = img.signature
         img.blue_shift(1.5)
@@ -236,6 +237,15 @@ def test_chop():
         assert img.height == (h - 10)
 
 
+def test_chop_gravity():
+    with Image(filename='rose:') as img:
+        img.chop(width=10, height=10, gravity='south_east')
+        assert (60, 36, 0, 0) == img.page
+    with raises(ValueError):
+        with Image(filename='rose:') as img:
+            img.chop(x=10, gravity='north')
+
+
 @mark.skipif(MAGICK_VERSION_NUMBER < 0x709,
              reason="Clahe requires Imagemagick-7.0.9.")
 def test_clahe():
@@ -856,6 +866,17 @@ def test_extent(fx_asset):
             img.extent(height=-10)
 
 
+def test_extent_gravity():
+    with Image(filename='rose:') as img:
+        img.extent(width=10, height=10, gravity='south_east')
+        assert (10, 10, 0, 0) == img.page
+        img.extent(width=100, height=100, gravity='center')
+        assert (100, 100, 0, 0) == img.page
+    with raises(ValueError):
+        with Image(filename='rose:') as img:
+            img.extent(x=10, gravity='north')
+
+
 def test_features():
     with Image(filename='rose:') as img:
         cf = img.features(10)
@@ -958,8 +979,8 @@ def test_fx(fx_asset):
 
 def test_fx_error(fx_asset):
     with Image() as empty_wand:
-        with raises(AttributeError):
-            with empty_wand.fx('8'):
+        with raises(WandRuntimeError):
+            with empty_wand.fx('8') as _:
                 pass
     with Image(filename='rose:') as xc:
         with raises(OptionError):
@@ -1177,6 +1198,20 @@ def test_kuwahara():
         assert was != img.signature
 
 
+def test_label(fx_asset):
+    font_path = str(fx_asset.join('League_Gothic.otf'))
+    with Image(filename='rose:') as img:
+        was = img.signature
+        img.label('a', left=0, top=0, font=Font(font_path, 12))
+        now = img.signature
+        assert now != was
+        img.label('b', font=Font(font_path, 12), gravity='south')
+        assert img.signature != now
+    with raises(TypeError):
+        with Image(filename='rose:') as img:
+            img.label('x')
+
+
 def test_level(fx_asset):
     with Image(filename=str(fx_asset.join('gray_range.jpg'))) as img:
         # Adjust the levels to make this image entirely black
@@ -1714,6 +1749,23 @@ def test_range_threshold():
         img.range_threshold(20, 40, 60)
 
 
+def test_region():
+    with Image(filename='rose:') as src:
+        w, h, x, y = src.page
+        with src.region() as dst:
+            assert (w, h) == dst.size
+        with src.region(width=w//2, height=h//2, x=x//2, y=y//2) as dst:
+            assert (w//2, h//2) == dst.size
+    with Image(filename='rose:') as src:
+        with src.region(width=10, height=10, gravity='south_east') as dst:
+            assert (70, 46, 60, 36) == dst.page
+            assert (10, 10) == dst.size
+    with raises(ValueError):
+        with Image(filename='rose:') as img:
+            with img.region(x=10, gravity='center') as _:
+                pass
+
+
 def test_remap(fx_asset):
     with Image(filename='rose:') as img:
         was = img.signature
@@ -1856,6 +1908,13 @@ def test_resize_and_sample_gif(method, tmpdir, fx_asset):
     tmpdir.remove()
 
 
+def test_roll():
+    with Image(filename='rose:') as img:
+        was = img.signature
+        img.roll(x=-15, y=15)
+        assert was != img.signature
+
+
 @mark.slow
 def test_rotate(fx_asset):
     """Rotates an image."""
@@ -1988,7 +2047,7 @@ def test_shade(fx_asset):
             img.shade(elevation='hello')
 
 
-def test_shadow(fx_asset):
+def test_shadow():
     with Image(filename='rose:') as img:
         was = img.size
         img.shadow(alpha=5.0, sigma=1.25, x=10, y=10)
@@ -2003,7 +2062,7 @@ def test_shadow(fx_asset):
             img.shadow(y=None)
 
 
-def test_sharpen(fx_asset):
+def test_sharpen():
     with Image(filename='rose:') as img:
         was = img.signature
         img.sharpen(radius=10.0, sigma=2.0)
@@ -2018,7 +2077,7 @@ def test_sharpen(fx_asset):
         assert was != img.signature
 
 
-def test_shave(fx_asset):
+def test_shave():
     with Image(filename='rose:') as img:
         was = img.size
         img.shave(10, 10)
@@ -2030,10 +2089,10 @@ def test_shave(fx_asset):
 
 
 def test_shear():
-    green = Color('GREEN')
     with Image(filename='rose:') as img:
+        was = img.signature
         img.shear(background='green', x=10, y=10)
-        assert img[0, 0] == green
+        assert was != img.signature
 
 
 def test_sigmoidal_contrast():
@@ -2113,7 +2172,7 @@ def test_sparse_color():
             img.sparse_color('barycentric', colors, channel_mask='red')
 
 
-def test_splice(fx_asset):
+def test_splice():
     green = Color('GREEN')
     with Image(filename='rose:') as img:
         width, height = img.size
@@ -2121,16 +2180,23 @@ def test_splice(fx_asset):
         img.splice(10, 10, 10, 10)
         assert width+10, height+10 == img.size
         assert img[15, 15] == green
+    with Image(filename='rose:') as img:
+        was = img.signature
+        img.splice(width=10, height=10, gravity='center')
+        assert img.signature != was
+    with raises(ValueError):
+        with Image(filename='rose:') as img:
+            img.splice(width=10, height=10, x=10, gravity='center')
 
 
-def test_spread(fx_asset):
+def test_spread():
     with Image(filename='rose:') as img:
         was = img.signature
         img.spread(8.0)
         assert was != img.signature
 
 
-def test_statistic(fx_asset):
+def test_statistic():
     with Image(filename='rose:') as img:
         was = img.signature
         img.statistic('median', 5, 5)
@@ -2216,7 +2282,7 @@ def test_thumbnail():
         assert (img.width, 20) == img.size
 
 
-def test_tint(fx_asset):
+def test_tint():
     with Image(filename='rose:') as img:
         was = img.signature
         img.tint('blue', 'blue')
@@ -2413,7 +2479,7 @@ def test_trim_reset_coords():
         assert page != img.page
 
 
-def test_unique_colors(fx_asset):
+def test_unique_colors():
     with Image(filename='rose:') as img:
         was = img.signature
         img.unique_colors()
@@ -2432,7 +2498,7 @@ def test_unsharp_mask(fx_asset):
         assert was != img.signature
 
 
-def test_vignette(fx_asset):
+def test_vignette():
     with Image(filename='rose:') as img:
         was = img.signature
         img.vignette(radius=3, sigma=3)
@@ -2442,19 +2508,13 @@ def test_vignette(fx_asset):
 def test_watermark(fx_asset):
     """Adds  watermark to an image."""
     with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
+        was = img.signature
         with Image(filename=str(fx_asset.join('watermark.png'))) as wm:
-            a = img[70, 83]
-            b = img[70, 84]
-            c = img[623, 282]
-            d = img[622, 281]
             img.watermark(wm, 0.3)
-            assert img[70, 83] == a
-            assert img[70, 84] != b
-            assert img[623, 282] == c
-            assert img[622, 281] != d
+            assert was != img.signature
 
 
-def test_wave(fx_asset):
+def test_wave():
     with Image(filename='rose:') as img:
         was = img.size
         img.wave(amplitude=img.height, wave_length=img.width/2)
@@ -2485,7 +2545,7 @@ def test_white_balance():
         assert was != img.signature
 
 
-def test_white_threshold(fx_asset):
+def test_white_threshold():
     with Image(filename='rose:') as img:
         was = img.signature
         img.white_threshold(Color('gray(50%)'))
