@@ -16,6 +16,7 @@ from pytest import mark, raises
 from wand.image import ClosedImageError, Image
 from wand.color import Color
 from wand.compat import PY3, text, text_type
+from wand.font import Font
 
 try:
     filesystem_encoding = sys.getfilesystemencoding()
@@ -260,6 +261,7 @@ def test_image_swap():
     with raises(TypeError):
         a.image_swap('a', 'b')
 
+
 def test_ping_from_filename(fx_asset):
     file_path = str(fx_asset.join('mona-lisa.jpg'))
     with Image.ping(filename=file_path) as img:
@@ -359,24 +361,35 @@ def test_make_blob(fx_asset):
         assert img.format == 'JPEG'
         with raises(TypeError):
             img.make_blob(123)
-    svg = b'''
-    <svg width="100px" height="100px">
-        <circle cx="100" cy="50" r="40" stroke="black"
-         stroke-width="2" fill="red" />
-    </svg>
+    pbm = b'''P1
+    4 4
+    0 1 0 1
+    1 0 1 0
+    0 1 0 1
+    1 0 1 0
     '''
-    with Image(blob=svg, format='svg') as img:
-        assert img.size == (100, 100)
-        assert img.format in ('SVG', 'MVG')
+    png = None
+    with Image(blob=pbm, format='pbm') as img:
+        assert img.size == (4, 4)
         img.format = 'PNG'
-        assert img.size == (100, 100)
-        assert img.format == 'PNG'
         png = img.make_blob()
     with Image(blob=png, format='png') as img:
-        assert img.size == (100, 100)
+        assert img.size == (4, 4)
         assert img.format == 'PNG'
 
 
+def test_montage():
+    with Image() as base:
+        for label in ['foo', 'bar', 'baz']:
+            with Image(width=10, height=10, pseudo='plasma:') as img:
+                img.options['label'] = label
+                base.image_add(img)
+        style = Font('monospace', 16, 'blue', False, 'orange')
+        base.montage(font=style, tile="2x2", thumbnail="16x16", mode="frame",
+                     frame="5x5")
+        assert base.iterator_length() == 1
+
+
 def test_convert(fx_asset):
     """Converts the image format."""
     with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
